@@ -1,39 +1,46 @@
 import bybit
 #
-client = bybit.bybit(test=True, api_key="", api_secret="")
+client = bybit.bybit(test=True, api_key="rHWpqFVAnlTdqTNODX", api_secret="eDZZGzzkojYaf96xKUowGOhlNQEuebOPNEE1")
 #
 # # # Get server time
 # print(client.Common.Common_get().result()[0])
-# #
+#
 # # # Get Symbol lists
 # print(client.Symbol.Symbol_get().result()[0]["result"][0])
+
+# #
+# # # Get public trading lists
+# print(client.Market.Market_tradingRecords(symbol="BTCUSD").result()[0]["result"][0])
 # #
 # # # Change account user leverage
 # print(client.Positions.Positions_saveLeverage(symbol="BTCUSD", leverage="14").result())
 # #
+# # # Change account user leverage
+# print(client.Positions.Positions_closePnlRecords(symbol="BTCUSD").result()[0]["result"][0])
+# #
 # # # Query account positions
 # print(client.Positions.Positions_myPosition().result())
 # #
 # # #Place an Active Order
-# print(client.Order.Order_newV2(side="Buy",symbol="BTCUSD",order_type="Limit",qty=1,price=8300,time_in_force="GoodTillCancel").result())
+# print(client.Order.Order_new(side="Buy",symbol="BTCUSD",order_type="Limit",qty=1,price=8300,time_in_force="GoodTillCancel").result())
 # #
 # # #Get Active Order
 # print(client.Order.Order_getOrders().result())
 # #
 # # #Cancel Active Order
-print(client.Order.Order_cancelV2(symbol="BTCUSD", order_id="69bd5b88-fa2e-4c33-a489-1860f595191d").result())
+# print(client.Order.Order_cancel(symbol="BTCUSD", order_id="b441f0e6-a105-46fb-af81-4beb01bdeed8").result())
 # #
 # # # Place Conditional Order
-# print(client.Conditional.Conditional_new(order_type="Limit",side="Buy",symbol="BTCUSD",qty=1,price=8100,base_price=8300,stop_px=8150,time_in_force="GoodTillCancel", order_link_id="cus_order_id_1").result())
+# print(client.Conditional.Conditional_new(order_type="Limit",side="Buy",symbol="BTCUSD",qty=1,price=8100,base_price=8300,stop_px=8150,time_in_force="GoodTillCancel", order_link_id="cus_order_id_2").result())
 # #
 # # #Get Conditional Order
 # print(client.Conditional.Conditional_getOrders(stop_order_status="Untriggered").result())
 # #
 # # #Cancel conditional order
-# print(client.Conditional.Conditional_cancel(symbol="BTCUSD", order_link_id="cus_order_id_1").result())
+# print(client.Conditional.Conditional_cancel(symbol="BTCUSD", stop_order_id="a85b7718-aba9-4a6a-be02-90502012c4b5").result())
 # #
 # # #changeMargin
-# print(client.Positions.Positions_changeMargin(symbol="BTCUSD", margin="10").result())
+# print(client.Positions.Positions_changeMargin(symbol="BTCUSD", margin="0.10").result())
 # #
 # # #Set Trading-Stop
 # print(client.Positions.Positions_tradingStop(symbol="BTCUSD",stop_loss="8100").result())
@@ -84,5 +91,8 @@ print(client.Order.Order_cancelV2(symbol="BTCUSD", order_id="69bd5b88-fa2e-4c33-
 # print(client.LinearFunding.LinearFunding_predicted(symbol="BTCUSDT").result())
 # print(client.LinearKline.LinearKline_get(symbol="BTCUSDT", interval="m", limit=10, **{'from':1}).result())
 # print(client.LinearKline.LinearKline_markPrice(symbol="BTCUSDT", interval="m", limit=10, **{'from':1}).result())
-#
+# print(client.LinearOrder.LinearOrder_replace(symbol="BTCUSDT", order_id="041b4ff9-e781-43a0-9a05-159598e10293", p_r_qty="0.001").result())
+# print(client.Market.Market_openInterest(symbol="BTCUSDT", limit=2, period="5min").result())
+# print(client.Market.Market_accountRatio(symbol="BTCUSDT", limit=2, period="5min").result())
+# print(client.Market.Market_bigDeal(symbol="BTCUSDT", limit=2).result())
 
